
class Module2(object):

    def __init__(self):
        x = 0

    def func2(a, b):
        return a * b